---
title: Installation
has_children: true
nav_order: 20
description: How to install and get started pair programming with aider.
---

# Quick start

{% include get-started.md %}

Or see the
[full installation instructions](/docs/install/install.html)
for more details,
or the
[usage instructions](https://aider.chat/docs/usage.html) to start coding with aider.

<div class="video-container">
  <video controls poster="/assets/install.jpg">
    <source src="/assets/install.mp4" type="video/mp4">
    <a href="/assets/install.mp4">Installing aider</a>
  </video>
</div>

<style>
.video-container {
  position: relative;
  padding-bottom: 76.2711864407%;
  height: 0;
  overflow: hidden;
}

.video-container video {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}
</style>



